==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var RangeCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeCategorySeriesDescriptionMetadata, _super);
    function RangeCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RangeCategorySeriesDescriptionMetadata.b = function (a) {
        if (RangeCategorySeriesDescriptionMetadata.a == null) {
            RangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RangeCategorySeriesDescriptionMetadata.c(RangeCategorySeriesDescriptionMetadata.a);
        }
        if (a.g(RangeCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(RangeCategorySeriesDescriptionMetadata.a);
    };
    RangeCategorySeriesDescriptionMetadata.c = function (a) {
        CategorySeriesDescriptionMetadata.c(a);
        a.item("LowMemberPath", "String");
        a.item("HighMemberPath", "String");
    };
    RangeCategorySeriesDescriptionMetadata.d = function (a) {
        RangeCategorySeriesDescriptionMetadata.b(a);
        a.t("RangeCategorySeries", RangeCategorySeriesDescriptionMetadata.a);
    };
    RangeCategorySeriesDescriptionMetadata.$t = markType(RangeCategorySeriesDescriptionMetadata, 'RangeCategorySeriesDescriptionMetadata');
    RangeCategorySeriesDescriptionMetadata.a = null;
    return RangeCategorySeriesDescriptionMetadata;
}(Base));
export { RangeCategorySeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var RangeCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RangeCategorySeriesDescriptionMetadata, _super);
    function RangeCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RangeCategorySeriesDescriptionMetadata.b = function (a) {
        if (RangeCategorySeriesDescriptionMetadata.a == null) {
            RangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RangeCategorySeriesDescriptionMetadata.c(RangeCategorySeriesDescriptionMetadata.a);
        }
        if (a.j(RangeCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(RangeCategorySeriesDescriptionMetadata.a);
    };
    RangeCategorySeriesDescriptionMetadata.c = function (a) {
        CategorySeriesDescriptionMetadata.c(a);
        a.item("LowMemberPath", "String");
        a.item("HighMemberPath", "String");
    };
    RangeCategorySeriesDescriptionMetadata.d = function (a) {
        RangeCategorySeriesDescriptionMetadata.b(a);
        a.z("RangeCategorySeries", RangeCategorySeriesDescriptionMetadata.a);
    };
    RangeCategorySeriesDescriptionMetadata.$t = markType(RangeCategorySeriesDescriptionMetadata, 'RangeCategorySeriesDescriptionMetadata');
    RangeCategorySeriesDescriptionMetadata.a = null;
    return RangeCategorySeriesDescriptionMetadata;
}(Base));
export { RangeCategorySeriesDescriptionMetadata };
